﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;
using System.Text;
using WebChatApi.Common.Interface;

namespace WebChatApi.Common
{
    /// <summary>
    /// Class for user info.
    /// </summary>
    [DataContract]
    [KnownType(typeof(BaseObject))]
    
    public class UserInfo : BaseObject, IIdentifiable
    {
        #region Properties

        /// <summary>
        /// Gets or sets the display name of the user.
        /// </summary>
        /// <value>
        /// The display name of the user.
        /// </value>
        [DataMember]
        public string UserDisplayName
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the first name.
        /// </summary>
        /// <value>
        /// The first name.
        /// </value>
        [DataMember]
        public string FirstName
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the last name.
        /// </summary>
        /// <value>
        /// The last name.
        /// </value>
        [DataMember]
        public string LastName
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the name of the middle.
        /// </summary>
        /// <value>
        /// The name of the middle.
        /// </value>
        [DataMember]
        public string MiddleName
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the gender.
        /// </summary>
        /// <value>
        /// The gender.
        /// </value>
        [DataMember]
        public Gender Gender
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the birthday.
        /// </summary>
        /// <value>
        /// The birthday.
        /// </value>
        [DataMember]
        public DateTime? Birthday
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the culture info.
        /// </summary>
        /// <value>
        /// The culture info.
        /// </value>
        [DataMember]
        public string CultureInfo
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the avator code.
        /// </summary>
        /// <value>
        /// The avator code.
        /// </value>
        [DataMember]
        public string AvatorCode
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the type of the source.
        /// </summary>
        /// <value>
        /// The type of the source.
        /// </value>
        [DataMember]
        public ApplicationSource SourceType
        {
            get;
            set;
        }

        #endregion

        #region Constructor

        /// <summary>
        /// Initializes a new instance of the <see cref="UserInfo"/> class.
        /// </summary>
        public UserInfo()
            : base()
        {
        }

        #endregion
    }
}
