﻿using WebChatApi.Common.Interface;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Runtime.Serialization;

namespace WebChatApi.Common
{
    /// <summary>
    /// Generic class for service response. 
    /// </summary>
    /// <typeparam name="T"></typeparam>
    [DataContract(Name = "ServiceResponseOf{0}")]
    [KnownType(typeof(ExceptionInfo))]
    public class ServiceResponse<T> : IServiceResponse
    {
        /// <summary>
        /// Gets a value indicating whether this instance is success. <c>Set</c> operation is for serialization compatibility only.
        /// </summary>
        /// <value>
        /// <c>true</c> if this instance is success; otherwise, <c>false</c>.
        /// </value>
        [DataMember]
        public bool IsSuccess
        {
            get
            {
                return this.ExceptionInfo == null;
            }
            set
            {
                //Do nothing
            }
        }

        /// <summary>
        /// Gets or sets the exception info.
        /// </summary>
        /// <value>
        /// The exception info.
        /// </value>
        [DataMember]
        public ExceptionInfo ExceptionInfo
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the data.
        /// </summary>
        /// <value>
        /// The data.
        /// </value>
        [DataMember]
        public virtual T Data
        {
            get;
            set;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ServiceResponse{T}"/> class.
        /// </summary>
        public ServiceResponse()
        {
        }

        /// <summary>
        /// To the ajax result.
        /// </summary>
        /// <returns></returns>
        public AjaxResult ToAjaxResult()
        {
            AjaxResult result = new AjaxResult();

            result.Data = this.Data;
            result.IsSuccess = this.IsSuccess;
            result.ErrorMessage = this.ExceptionInfo.ToString();

            return result;
        }
    }
}
