﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.IO;
using System.Linq;
using System.Net;
using System.Net.Mail;
using System.Runtime.InteropServices;
using System.Text;
using System.Threading.Tasks;
using System.Web;

namespace WebChatApi.Common
{
    /// <summary>
    /// Interface for console worker
    /// </summary>
    public interface IConsoleWorker
    {
        #region Properties

        /// <summary>
        /// Gets or sets the success count.
        /// </summary>
        /// <value>
        /// The success count.
        /// </value>
        int SuccessCount { get; }

        /// <summary>
        /// Gets or sets the failed count.
        /// </summary>
        /// <value>
        /// The failed count.
        /// </value>
        int FailedCount { get; }

        /// <summary>
        /// Gets or sets the start stamp.
        /// </summary>
        /// <value>
        /// The start stamp.
        /// </value>
        DateTime StartStamp { get; }

        /// <summary>
        /// Gets the running thread count.
        /// </summary>
        /// <value>
        /// The running thread count.
        /// </value>
        int RunningThreadCount { get; }

        #endregion

        /// <summary>
        /// Increases the success count.
        /// </summary>
        /// <param name="value">The value.</param>
        void IncreaseSuccessCount(int value = 1);

        /// <summary>
        /// Increases the failed count.
        /// </summary>
        /// <param name="value">The value.</param>
        void IncreaseFailedCount(int value = 1);

        /// <summary>
        /// Does the work.
        /// </summary>
        void DoWork();
    }
}
